#!/usr/bin/env node

'use strict';

var program = require('commander');
var fs = require("fs");
var path = require("path")
var cmdProcess = require('child_process');

/**
  program
 .version('0.0.1')
 .command('importSql [host] [user] [pwd] <sql>')
 .option('-i, --integer <n>', 'An integer argument', parseInt)
 .option('-f, --float <n>', 'A float argument', parseFloat)
 .option('-r, --range <a>..<b>', 'A range', range)
 .option('-l, --list <items>', 'A list', list)
 .option('-o, --optional [value]', 'An optional value')
 .option('-c, --collect [value]', 'A repeatable value', collect, [])
 .option('-v, --verbose', 'A value that can be increased', increaseVerbosity, 0)
 .parse(process.argv);
 *
 * */

program
    .version('0.0.1');

program
    .command('importSql')
    .description('Import a .sql to MySql database')
    .option('-h, --host [value]', 'The MySql host', '127.0.0.1')
    .option('-u, --user [value]', 'The MySql user, default is root', 'root')
    .option('-p, --pwd [value]', 'The MySql user password, default is root', 'root')
    .option('-s, --sql <value>', 'The .sql or a folder with .sql files to be imported')
    .action(function() {
        var params = arguments[0];
        if(params.sql == null) throw "Need a .sql or folder with .sql!";

        //参见：https://www.npmjs.com/package/execsql
        var cmd = 'execsql -c "' + params.host +'" "' + params.user + '" "' + params.pwd + '"';

        var sql = params.sql;

        if(sql.indexOf(".sql") > 0) {
            cmd +=' && execsql -f ' + sql;
        } else {
            var stats = fs.statSync(sql);
            if(stats.isDirectory()) {
                var files = fs.readdirSync(sql);
                for(var i = 0; i < files.length; i++) {
                    var file = path.join(sql, files[i]);
                    if(file.indexOf(".sql") > 0) {
                        cmd +=' && execsql -f ' + file;
                    }
                }
            } else {
                throw "The sql must be a .sql file or a folder contains .sql files!"
            }
        }

        var exec = cmdProcess.exec(cmd);

        exec.stdout.on('data', function (info) {
            if(info.length > 1) console.log(info);
        });
        exec.stderr.on('data', function (err) {
            if(err.length > 1) console.log(err);
        });
        exec.on('exit', function (code) {
            console.log('child process exited with code ' + code);
        });

        exec.on('error', function (code) {
            console.log('child process exited with code ' + code);
        });

    });

program.parse(process.argv);
